package com.ruoyi.frequency.block.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.controller.req.BlockPageReq;
import com.ruoyi.controller.req.BlockUserReq;
import com.ruoyi.frequency.block.entity.Block;
import com.ruoyi.response.ResponseData;
import com.ruoyi.vo.UserVo;

import java.util.List;

/**
 * 拉黑Service接口
 * 
 * @author liwenlong
 * @date 2023-07-22
 */
public interface BlockService extends IService<Block>
{
    /**
     * 查询拉黑
     * 
     * @param id 拉黑主键
     * @return 拉黑
     */
    public Block selectBlockById(Long id);

    /**
     * 查询拉黑列表
     * 
     * @param block 拉黑
     * @return 拉黑集合
     */
    public List<Block> selectBlockList(Block block);

    /**
     * 新增拉黑
     * 
     * @param block 拉黑
     * @return 结果
     */
    public int insertBlock(Block block);

    /**
     * 修改拉黑
     * 
     * @param block 拉黑
     * @return 结果
     */
    public int updateBlock(Block block);

    /**
     * 批量删除拉黑
     * 
     * @param ids 需要删除的拉黑主键集合
     * @return 结果
     */
    public int deleteBlockByIds(Long[] ids);

    /**
     * 删除拉黑信息
     * 
     * @param id 拉黑主键
     * @return 结果
     */
    public int deleteBlockById(Long id);

    /**
     * 拉黑用户
     * @param req
     * @param userVo
     * @return
     */
    ResponseData blockUser(BlockUserReq req, UserVo userVo);

    /**
     * 拉黑用户列表（自己查看）
     * @param req
     * @param userVo
     * @return
     */
    ResponseData blockPage(BlockPageReq req, UserVo userVo);

    /**
     * 拉黑用户列表（他人查看）
     * @param req
     * @return
     */
    ResponseData otherBlockPage(BlockPageReq req,UserVo userVo);

    ResponseData blockUserVersion2(BlockUserReq req, UserVo userVo);

    ResponseData cancelBlockUserVersion2(BlockUserReq req, UserVo userVo);
}
